package com.example.arqdemo;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.spec.JavaArchive;
import org.junit.*;
import org.junit.runner.RunWith;

//
// This test demonstrates the order in which things happen in an Arquillian
// test execution.
// 
// When you run this test, the client-side mesages are emitted in the
// "mvn test" output to the console, and the server-side messages are
// sent to the application server logs.
//
@RunWith(Arquillian.class)
public class OrderingTest {

    // If it exists, this method runs on the client (outside the container)
    // It does *not* also get run in the container, at least for JUnit+Arquillian.
    @BeforeClass
    public static void runsOnClientBeforeAllTests() {
        System.err.println("BeforeClass");
    }
    
    // As @BeforeClass, runs on client
    @AfterClass
    public static void runsOnClientAfterAllTests() {
        System.err.println("BeforeClass");
    }
    @Deployment
    public static JavaArchive createDeployment() {
        System.err.println("createDeployment()");
        return ShrinkWrap.create(JavaArchive.class);
    }
    
  
    // The ctor runs once on the server for each @Test, because the whole
    // test lifecycle runs on the server for each test.
    //
    // There's no guarantee that instances of the class won't also be
    // created client-side. In general, it's best to use the annotated
    // lifecycle methods rather than the constructor.
    //
    public OrderingTest() {
        System.err.println("OrderingTest() ctor");
    }
    
    // The @Before method(s) are run on the server before each test. 
    // There is no container-side equivalent of @BeforeClass that runs
    // only once before any tests are run.
    @Before
    public void runsOnServerBeforeEachTest() {
        System.err.println("@Before");
    }
    
    @After
    public void runsOnServerAfterEachTest() {
        System.err.println("@After");
    }
    
    @Test
    public void test1() {
        System.err.println("test1()");
    }
    
    @Test
    public void test2() {
        System.err.println("test2()");
    }
    
}
